package com.meas.system.mapper;

import com.meas.system.domain.MeasEnvData;

import java.util.List;

/**
 * 测量环境数据Mapper接口
 *
 * @author wgk
 * @date 2024-06-13
 */
public interface MeasEnvDataMapper {
    /**
     * 查询测量环境数据
     *
     * @param id 测量环境数据主键
     * @return 测量环境数据
     */
    public MeasEnvData selectMeasEnvDataById(Long id);

    /**
     * 查询测量环境数据列表
     *
     * @param measEnvData 测量环境数据
     * @return 测量环境数据集合
     */
    public List<MeasEnvData> selectMeasEnvDataList(MeasEnvData measEnvData);

    /**
     * 新增测量环境数据
     *
     * @param measEnvData 测量环境数据
     * @return 结果
     */
    public int insertMeasEnvData(MeasEnvData measEnvData);

    /**
     * 修改测量环境数据
     *
     * @param measEnvData 测量环境数据
     * @return 结果
     */
    public int updateMeasEnvData(MeasEnvData measEnvData);

    /**
     * 删除测量环境数据
     *
     * @param id 测量环境数据主键
     * @return 结果
     */
    public int deleteMeasEnvDataById(Long id);

    /**
     * 批量删除测量环境数据
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMeasEnvDataByIds(Long[] ids);
}
